@@ -30,8 +30,8 @@ class InvoicesApi(BaseApi):
                 previous call to this endpoint.  Provide this cursor to
                 retrieve the next set of results for your original query.  For
                 more information, see
-                [Pagination](https://developer.squareup.com/docs/docs/working-w
-                ith-apis/pagination).
+                [Pagination](https://developer.squareup.com/docs/working-with-a
+                pis/pagination).
             limit (int, optional): The maximum number of invoices to return
                 (200 is the maximum `limit`).  If not provided, the server 
                 uses a default limit of 100 invoices.
